Kills the background process and stops its polling timer.
Arguments
- app
An
RtuiAppobject.- name
Name of the task to cancel (as passed to
run_async()).
Kills the background process and stops its polling timer.
An RtuiApp object.
Name of the task to cancel (as passed to run_async()).