Renders a data.frame as a formatted static table (non-interactive).
For an interactive table with sorting and selection, see data_table().
Renders a data.frame as a formatted static table (non-interactive).
For an interactive table with sorting and selection, see data_table().