The current screen is preserved and a new screen is shown on top.
Use pop_screen() from a callback to dismiss it.
Arguments
- app
An
RtuiAppobject (must be running).- screen
A screen spec created with
tui_screen().
The current screen is preserved and a new screen is shown on top.
Use pop_screen() from a callback to dismiss it.
An RtuiApp object (must be running).
A screen spec created with tui_screen().