Workers are timers that poll an R function at a given interval. The worker
fires "timer" events at each tick; handle with app$handlers$timer.
This is a convenience wrapper around set_interval() for polling patterns.
Workers are timers that poll an R function at a given interval. The worker
fires "timer" events at each tick; handle with app$handlers$timer.
This is a convenience wrapper around set_interval() for polling patterns.