Skip to contents

Renders charts directly in the terminal using plotext via textual-plotext. The widget displays an empty plot area at creation time. Use the plot_*() family of functions to draw data from callbacks.

Usage

text_plot(id = NULL, classes = NULL)

Arguments

id

Optional widget id (required if you want to update the plot later).

classes

Optional CSS classes (character vector).

Value

An rtui_spec list.