Queries all widget ids from a form and returns a named list of their current values. This is called automatically when the form submit button is clicked, but you can also call it manually from any handler.
Queries all widget ids from a form and returns a named list of their current values. This is called automatically when the form submit button is clicked, but you can also call it manually from any handler.