Dismisses the top screen, returning to the screen below. Optionally
passes a result value back which is dispatched as a "screen_result"
event (handle via app$handlers$screen_result).
Dismisses the top screen, returning to the screen below. Optionally
passes a result value back which is dispatched as a "screen_result"
event (handle via app$handlers$screen_result).