Renders charts directly in the terminal using plotext via textual-plotext.
The widget displays an empty plot area at creation time. Use the plot_*()
family of functions to draw data from callbacks.
Details
Available chart types: plot_bar(), plot_line(), plot_scatter(),
plot_hist(), plot_box(), plot_stacked_bar(), plot_multiple_bar(),
plot_heatmap(), plot_candlestick(), plot_error(), plot_event().