Text output component
tuiOutputText.RdDisplays the value of output$<outputId> as text.
Usage
tuiOutputText(
outputId,
wrap = FALSE,
overflow = NULL,
width = NULL,
height = NULL,
minHeight = NULL,
maxHeight = NULL,
widthPercent = NULL,
heightPercent = NULL
)Arguments
- outputId
A single character string naming the output id.
- wrap
Backward-compatible shortcut for wrapped text. If
TRUE, this behaves likeoverflow = "wrap". IfFALSE(default), behavior is controlled byoverflow.- overflow
Text overflow policy. Use
"clip"(default) to keep a single line clipped to available width,"wrap"to wrap text to available width, or"ellipsis"to keep one line and truncate with an ellipsis when content exceeds the available width.- width, height
Optional fixed width/height in terminal cells.
- minHeight, maxHeight
Optional min/max height in terminal cells.
- widthPercent, heightPercent
Optional relative size between
0and1.widthPercentis interpreted bytuiRow()andheightPercentbytuiColumn()for strict main-axis percentages.